/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import YAWM from 'yawn-yaml/cjs';
import { ValidateFunction } from 'ajv';
/**
 * A meta-data representation of a schema file
 * providing path and type.
 */
export interface SchemaFile {
    path: string;
    type: 'json' | 'yaml';
}
export declare abstract class SchemaDocumentInstance {
    protected yawn: YAWM;
    type: string;
    /** If true the document was parsed and validated successfully.
     *  If false then pasing or validation failed. Check the errorMessages members then.  */
    isValid: boolean;
    /** Provides meta-data for the file used to create the instance using the SchemaFile interface */
    file: SchemaFile | undefined;
    /** Error message resulting from IO errors, parsing, or validations. TODO: requires localization */
    errorMessages: string | undefined;
    protected static validationFunction: ValidateFunction | undefined;
    /**
     * Creates an instance of SchemaDocumentInstance. Protected, use factory methods instead.
     * @param {string} schemaYamlString String representation of the yaml used to create the instance
     * @param {string} [errorMessages] Optionally provide error messages to be preserved such as IO errors from reading a file
     */
    protected constructor(schemaYamlString: string, errorMessages?: string);
    /**
     * @returns {(Type | undefined)} returns the schema document as an instance of the IBMSchemaDocument interface
     */
    abstract getAsDocument<Type>(): Type | undefined;
    /**
     * @returns {(string | undefined)} returns the schema document as YAML string
     */
    getAsYaml(): string | undefined;
    getAsJson(): string | undefined;
    /**
     * @returns {(Record<string, unknown> | undefined)} returns the schema document as untyped object
     */
    protected getAsObject(): Record<string, unknown> | undefined;
    /**
     * When running ZAPP in an editor then the editor will write file updates in a parallel process
     * than the ZAPP code that runs in an extension host in a parallel node instance. We observed
     * that sometime node's fs.readFile will then return an empty string. The theory is that the file is
     * still locked by the write process because the file contents have not yet been fully flushed to
     * the disk by the other process. As a work around we want to retry reading a file when it returns
     * empty. When an exception is throw then it will not retry.
     *
     * TODO: all the watcher and IO code should be moved into its own replaceable modules.
     *
     * @param filepath Absolute path to the file to read
     * @returns the contents of the file read or throws an exception if multiple attempts failed
     */
    protected static readFileWithRetry(filepath: string): Promise<string>;
    /**
     * If the document instance was read from a file and/or the file is populated with path and type
     * then write it back to the file system replacing the previous file.
     * TODO: expose via the document cache to deal with watchers correctly.
     */
    write(): void;
    /**
     * Can be called to check that the document complies with the schema json-schema.
     * If validation errors are found then they will added to the errorMessages member.
     * @returns {boolean} false if validation errors were found
     */
    abstract validate(): boolean;
    protected appendErrorMessage(message: string | undefined): void;
    protected prependErrorMessage(message: string | undefined): void;
}
