/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { ValidateFunction } from 'ajv';
import { SchemaDocumentInstance } from '../../schemas';
/**
 * A meta-data representation of a zapp file
 * providing path and type.
 */
export interface ZappFile {
    path: string;
    type: 'json' | 'yaml';
}
/**
 * Represent ZAPP documents that are stored either as yaml or json files.
 * Features various factory method to create instances for workspace locations or absolute file names.
 */
export declare class ZappDocumentInstance extends SchemaDocumentInstance {
    type: string;
    protected static validationFunction: ValidateFunction<unknown>;
    private static initAjvValidator;
    /**
     * Creates a ZappDocumentInstance with a yaml string.
     * @param {string} zappYamlString
     * @returns {ZappDocumentInstance}
     */
    static createFromYamlString(zappYamlString: string): ZappDocumentInstance;
    /**
     * Creates a ZappDocumentInstance with a json string.
     * @param {string} zappJsonString
     * @returns {ZappDocumentInstance}
     */
    static createFromJsonString(zappJsonString: string): ZappDocumentInstance;
    /**
     * Creates a ZappDocumentInstance with a yaml file path
     * @param {string} filepath absolute path name
     * @returns {Promise<ZappDocumentInstance>} promise that will resolve into an instantiated ZappDocumentInstance.
     *          If no document was found or it contained errors then these errors will be populated in the object.
     */
    static createFromYamlFile(filepath: string): Promise<ZappDocumentInstance>;
    /**
     * Creates a ZappDocumentInstance with a json file path
     * @param {string} filepath absolute path name
     * @returns {Promise<ZappDocumentInstance>} promise that will resolve into an instantiated ZappDocumentInstance.
     *          If no document was found or it contained errors then these errors will be populated in the object.
     */
    static createFromJsonFile(filepath: string): Promise<ZappDocumentInstance>;
    /**
     * Creates a ZappDocumentInstance from a file. Checks the file type automatically.
     * @param {string} filepath absolute path name
     * @returns {Promise<ZappDocumentInstance>} promise that will resolve into an instantiated ZappDocumentInstance.
     *          If no document was found or it contained errors then these errors will be populated in the object.
     */
    static createFromFile(filepath: string): Promise<ZappDocumentInstance>;
    /**
     * Creates a ZappDocumentInstance by looking for a zapp file in a directory.
     * Checks the file type automatically. Will always prioritize yaml over json.
     * @param {string} workspacePath absolute path name
     * @returns {Promise<ZappDocumentInstance>} promise that will resolve into an instantiated ZappDocumentInstance.
     *          If no document was found or it contained errors then these errors will be populated in the object.
     */
    static loadFromWorkspace(workspacePath: string): Promise<ZappDocumentInstance>;
    /**
     * Looks for zapp files in a directory. Will always prioritize yaml over json.
     * @param {string} workspacePath absolute path name
     * @returns {(ZappFile | undefined)} An instance of ZappFile or undefined if not found
     */
    static findZappFile(workspacePath: string): ZappFile | undefined;
    /**
     * @param {string} filename string that represent a filename; not a path
     * @returns {boolean} true if filename is either zapp.json, zapp.yml, or zapp.yaml
     */
    static isZappFileName(filename: string): boolean;
    /**
     * @returns {(IBMZappDocument | undefined)} returns the ZAPP document as an instance of the IBMZappDocument interface
     */
    getAsDocument<IBMZappDocument>(): IBMZappDocument | undefined;
    /**
     * Can be called to check that the document complies with the schema json-schema.
     * If validation errors are found then they will added to the errorMessages member.
     * @returns {boolean} false if validation errors were found
     */
    validate(): boolean;
}
