/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
/**
 * JSON schema for zapp.json and zapp.yaml files. Version 0.0.3 -- Licensed Materials - Property of IBM - (c) Copyright IBM Corporation 2021. All Rights Reserved.
 */
export declare type IBMZappDocument = CoreProperties;
/**
 * A person who has been involved in creating or maintaining this package
 */
export declare type Person = {
    name: string;
    url?: string;
    email?: string;
    [k: string]: unknown;
} | string;
/**
 * Profiles are additional groups of properties that should only should become valid under specific conditions such as running in a build job or as part of a debug session.
 */
export declare type Profile = {
    name: string;
    type: 'dbb';
    'property-groups'?: unknown[];
    settings: DbbSettingsItem;
} | {
    name: string;
    type: 'debug';
    settings: DebugSettingsItem;
} | {
    name: string;
    type: 'rseapi';
    settings: RseapiSettingsItem;
};
export interface CoreProperties {
    /**
     * The name of the Z Project.
     */
    name: string;
    /**
     * This helps people understand your project as it would be used by tools.
     */
    description?: string;
    /**
     * Version is a string and it must be parsable for managing dependencies.
     */
    version?: string;
    /**
     * Defines a group name that is shared for each application part in case of applications composed of multiple parts. Allows to uniquely identify the parts by concatenating with the artifact id. For example an group-id `com.ibm.wazi` with and artifact-id `service` would create the unique application identifier `com.ibm.wazi.service`.
     */
    'group-id'?: string;
    /**
     * Define id of the application artifact. Use it in combination with a group-id for multi-part applications.
     */
    'artifact-id'?: string;
    /**
     * In case of a multi-part application defines the name of the parent application part. This zapp will inherit properties such as property-groups defined in the parent.
     */
    'parent-id'?: string;
    /**
     * This helps people discover your project.
     */
    keywords?: string[];
    /**
     * The url to the project homepage.
     */
    homepage?: ({
        [k: string]: unknown;
    } | '.') & string;
    /**
     * You should specify a license for your package so that people know how they are permitted to use it, and any restrictions you're placing on it.
     */
    license?: string;
    author?: Person;
    /**
     * A list of people who contributed to this package.
     */
    contributors?: [Person, ...Person[]];
    /**
     * A list of people who maintains this package.
     */
    maintainers?: [Person, ...Person[]];
    /**
     * A list properties defining path names for resolving dependencies.
     */
    'property-groups'?: [PropertyGroupItem, ...PropertyGroupItem[]];
    /**
     * Profiles are additional groups of properties that should only should become valid under specific conditions such as running in a build job or as part of a debug session.
     */
    profiles?: [Profile, ...Profile[]];
    [k: string]: unknown;
}
export interface PropertyGroupItem {
    /**
     * The name of the property group, which is used in hovers and error messages.
     */
    name: string;
    /**
     * The type of the property group defining where dependencies should be located. Allowed values are 'local' for using a local workspace, 'mvs' for dependencies located in MVS Datasets and 'uss' for dependencies located in USS UNIX System Files.
     */
    type?: 'uss' | 'mvs' | 'local';
    /**
     * Limits the property group to one specific language.
     */
    language?: 'cobol' | 'pl1' | 'hlasm' | 'rexx' | 'jcl';
    /**
     * Global compiler options separated by comma that impact the parsing of the programs for the editor. Requires that you specify a language. If there are multiple Property Groups for a language with compiler option then they will be concatenated.
     */
    compilerOptions?: string;
    /**
     * The of the z/OS system against which the mvs or uss entries should be matched. This could be a url or parts of a URL that is used by some remote connection technology such as Wazi's Remote System Explorer connections.
     */
    system?: string;
    /**
     * An array of locations to locate dependencies for programs. Allowed values are absolute or relative file path names, if the type is 'local', or MVS Dataset Names, if the type is 'mvs', USS Unix System File Absolute Path is type is 'uss'.
     */
    syslib?: string[];
    /**
     * A Library name and an array of locations to locate dependencies for library references. Allowed values are file path names for that Library, if the type is 'local', or MVS Dataset Names, if the type is 'mvs' or USS Unix System File Absolute Path is type is 'uss'.
     */
    libraries?: [
        {
            /**
             * Name of the Library
             */
            name: string;
            /**
             * An array of locations to locate dependencies for the library. Allowed values are file path names, if the type is 'local', or MVS Dataset Names, if the type is 'mvs', USS Unix System File Absolute Path is type is 'uss'.
             */
            locations: unknown[];
        }
    ];
}
/**
 * DBB build script properties for running User Build on remote host.
 */
export interface DbbSettingsItem {
    /**
     * Command that build script is executed with.
     */
    command: string;
    /**
     * Parameters for build script.
     */
    buildScriptArgs?: unknown[];
    /**
     * The full path of build script on remote host.
     */
    buildScriptPath?: string;
    /**
     * Additional build dependencies from local host.
     */
    additionalDependencies?: unknown[];
}
/**
 * Debug properties for running a Debug session on a remote host.
 */
export interface DebugSettingsItem {
    /**
     * Debug is not yet supported by ZAPP.
     */
    unavailable: string;
}
/**
 * RSE API client settings for interactions with a z/OS remote host running an RSE API server.
 */
export interface RseapiSettingsItem {
    /**
     * A list of mapping objects that map local file extensions to transfer modes and encodings to MVS datasets that can be specified using wildcards.
     */
    mappings: RseapiSettingsItemMapping[];
    /**
     * The encoding to be used when no mapping can be found. If not provided then either the user or server default will be used.
     */
    'default.encoding': string;
}
/**
 * One mapping that contains at least transfer and resource values.
 */
export interface RseapiSettingsItemMapping {
    /**
     * A local file extension such as cbl or pl1.
     */
    extension?: string;
    /**
     * The transfer mode to be used. Can be 'text' or 'binary'.
     */
    transfer?: 'text' | 'binary';
    /**
     * The data set name to be mapped to. Can use a wildcard such as '**CPY'.
     */
    resource?: string;
    /**
     * The encoding to be used for text transfer. See the RSE API documentation for the values allowed.
     */
    encoding?: string;
    /**
     * A nested mappings array with resource mappings to members of the data sets that were mapped by the parent mapping.
     */
    memberMappings?: {
        /**
         * A local file extension such as cbl or pl1.
         */
        extension?: string;
        /**
         * The transfer mode to be used. Can be 'text' or 'binary'.
         */
        transfer?: 'text' | 'binary';
        /**
         * The encoding to be used for text transfer. See the RSE API documentation for the values allowed.
         */
        encoding?: string;
        /**
         * The data set member name to be mapped to. Can use a wildcard such as '**CPY'.
         */
        resource?: string;
    }[];
}
