/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { ValidateFunction } from 'ajv';
import { SchemaDocumentInstance } from '../../schemas/parser/schema-document-instance';
/**
 * A meta-data representation of a zCodeFormat file
 * providing path and type.
 */
export interface ZCodeFormatFile {
    path: string;
    type: 'json' | 'yaml';
}
/**
 * Represent ZCodeFormat documents that are stored either as yaml or json files.
 * Features various factory method to create instances for workspace locations or absolute file names.
 */
export declare class ZCodeFormatDocumentInstance extends SchemaDocumentInstance {
    type: string;
    protected static validationFunction: ValidateFunction<unknown>;
    private static initAjvValidator;
    /**
     * Creates a ZCodeFormatDocumentInstance with a yaml string.
     * @param {string} zCodeFormatYamlString
     * @returns {ZCodeFormatDocumentInstance}
     */
    static createFromYamlString(zCodeFormatYamlString: string): ZCodeFormatDocumentInstance;
    /**
     * Creates a ZCodeFormatDocumentInstance with a json string.
     * @param {string} zCodeFormatJsonString
     * @returns {ZCodeFormatDocumentInstance}
     */
    static createFromJsonString(zCodeFormatJsonString: string): ZCodeFormatDocumentInstance;
    /**
     * Creates a ZCodeFormatDocumentInstance with a yaml file path
     * @param {string} filenpath absolute path name
     * @returns {Promise<ZCodeFormatDocumentInstance>} promise that will resolve into an instantiated ZCodeFormatDocumentInstance.
     *          If no document was found or it contained errors then these errors will be populated in the object.
     */
    static createFromYamlFile(filenpath: string): Promise<ZCodeFormatDocumentInstance>;
    /**
     * Creates a ZCodeFormatDocumentInstance with a json file path
     * @param {string} filepath absolute path name
     * @returns {Promise<ZCodeFormatDocumentInstance>} promise that will resolve into an instantiated ZCodeFormatDocumentInstance.
     *          If no document was found or it contained errors then these errors will be populated in the object.
     */
    static createFromJsonFile(filepath: string): Promise<ZCodeFormatDocumentInstance>;
    /**
     * Creates a ZCodeFormatDocumentInstance from a file. Checks the file type automatically.
     * @param {string} filepath absolute path name
     * @returns {Promise<ZCodeFormatDocumentInstance>} promise that will resolve into an instantiated ZCodeFormatDocumentInstance.
     *          If no document was found or it contained errors then these errors will be populated in the object.
     */
    static createFromFile(filepath: string): Promise<ZCodeFormatDocumentInstance>;
    /**
     * Creates a ZCodeFormatDocumentInstance by looking for a zCodeFormat file in a directory.
     * Checks the file type automatically. Will always prioritize yaml over json.
     * @param {string} workspacePath absolute path name
     * @returns {Promise<ZCodeFormatDocumentInstance>} promise that will resolve into an instantiated ZCodeFormatDocumentInstance.
     *          If no document was found or it contained errors then these errors will be populated in the object.
     */
    static loadFromWorkspace(workspacePath: string): Promise<ZCodeFormatDocumentInstance>;
    /**
     * Looks for zCodeFormat files in a directory. Will always prioritize yaml over json.
     * @param {string} workspacePath absolute path name
     * @returns {(ZCodeFormatFile | undefined)} An instance of ZCodeFormatFile or undefined if not found
     */
    static findZCodeFormatFile(workspacePath: string): ZCodeFormatFile | undefined;
    /**
     * @param {string} filename string that represent a filename; not a path
     * @returns {boolean} true if filename is either zCodeFormat.json, zCodeFormat.yml, or zCodeFormat.yaml
     */
    static isZCodeFormatFileName(filename: string): boolean;
    /**
     * @returns {(ZCodeFormatSettings | undefined)} returns the ZCodeFormat document as an instance of the IBMZCodeFormatDocument interface
     */
    getAsDocument<ZCodeFormatSettings>(): ZCodeFormatSettings | undefined;
    /**
     * Can be called to check that the document complies with the schema json-schema.
     * If validation errors are found then they will added to the errorMessages member.
     * @returns {boolean} false if validation errors were found
     */
    validate(): boolean;
}
